from cpanlp.account.income.revenue import *
from cpanlp.entity.entity import *
from cpanlp.market.commodity import *
import math

class Market:
    def __init__(self,commodity,participants):
        self.commodity = commodity
        self.participants = participants
        self.transaction_costs = None
        self.free_entry=None
        self.number_of_participants = None 
class PerfectlyCompetitiveMarket(Market):
    def __init__(self, commodity, participants):
        #price takers
        super().__init__(commodity, participants)
        self.equilibrium_price = None
        self.equilibrium_quantity = None
        self.barriers = False
        self.free_entry = True
        self.number_of_participants = math.inf
    def calculate_equilibrium(self):
        # Code to calculate equilibrium price and quantity
        pass
class MonopolyMarket(Market):
    def __init__(self, commodity, businessentity):
        super().__init__(commodity, [])
        self.businessentity=businessentity
        self.profit_maximizing_price = None
        self.profit_maximizing_quantity = None
        self.market_demand = None
        self.total_cost = None
        self.barriers = True
        self.free_entry = False
class OligopolyMarket(Market):
    def __init__(self, commodity, participants):
        super().__init__(commodity, participants)
        self.barriers = True
        self.free_entry = False

    def price_setting(self):
        """Price setting behavior of firms in oligopoly market"""
        for firm in self.participants:
            if firm.market_leader:
                # Firm sets price based on competitors' reactions
                pass
            else:
                # Firm sets price based on market leader's price
                pass
            
def main():
    commodity=Commodity("苹果",5,30,10,20)
    llc=LegalEntity("科技公司","小企业",3000)
    llc1=LegalEntity("科技公司2","小企业2",3000)
    a= Market(commodity,[llc,llc1])
    print(a.commodity.demand)
if __name__ == '__main__':
    main()


from cpanlp.contract.contract import *
class LaborContract(Contract):
    accounts = []
    def __init__(self, parties, consideration,obligations,salary):
        super().__init__(parties, consideration,obligations)
        self.employee = None
        self.employer = None
        self.salary = salary
        LaborContract.accounts.append(self)


from cpanlp.person.consumer import *
from cpanlp.culture.spirit import *

class Entrepreneur(Consumer):
    def __init__(self, name, age,wealth,utility_function,experience,company,entrepreneurship):
        super().__init__(name, age,wealth,utility_function)
        self.entrepreneurship=entrepreneurship
        self.experience = experience
        self.company = company
        self.industry = ""
        self.employees = []
    def hire_employee(self, employee):
        self.employees.append(employee)
        print(f"{employee.name} has been hired by {self.company.name}.")
    def fire_employee(self, employee):
        self.employees.remove(employee)
        print(f"{employee.name} has been fired by {self.company.name}.")
    def list_employees(self):
        for employee in self.employees:
            print(employee.name)
    def raise_funds(self, amount):
        print(f"{self.company.name} has raised ${amount} in funding.")
    def acquire_company(self, company):
        print(f"{self.company.name} has acquired {company.name}.")
    def take_risk(self, risk):
        if risk > self.experience:
            print(self.name + " is taking a high risk.")
        else:
            print(self.name + " is taking a moderate risk.")
    def innovate(self):
        print(self.name + " is constantly seeking new and innovative ideas.")
    def persist(self):
        print(self.name + " is persistent in the face of failure.")
    def strive_for_excellence(self):
        print(self.name + " is always striving for excellence.")
def main():
    print("hello")
        # Create an Entrepreneur
    entre = Entrepreneurship()
    john = Entrepreneur("John Smith",30,1000000,0, 5,LLC("huawei","llc",5000),entre)
if __name__ == '__main__':
    main()


from typing import List
#The most important attribute of equity is its ability to represent the residual ownership interest in a company after all liabilities have been paid. This means that equity represents the value of a company that is left over for shareholders after all debts have been settled. Other important attributes of equity include its growth potential, as well as its risk and return characteristics. Additionally, factors such as the level of diversification, liquidity, and the quality of the underlying assets also important to consider when evaluating equity.
class Equity:
    accounts = []
    def __init__(self, account, value):
        self.account = account
        self.value = value
        self.equities: List[Equity] = []
        self.residual_ownership_interest=None
        self.growth_pontential=None
        self.risk_return = None
        self.diversification = None
        self.liquidity = None
        self.quality_of_underlying_assets=None
        Equity.accounts.append(self)
    def __str__(self):
        return f"{self.account}: {self.value}"
    def add_equity(self, account, value):
        self.equities.append(Equity(account, value))
    def withdraw_equity(self, account, value):
        for equity in self.equities:
            if equity.account == account:
                equity.value -= value
                break
    def sum(self):
        return sum([equity.value for equity in self.equities])
def main():
    a=Equity("张老板",1000)
    print(a)
    a.add_equity("liu",1000)
    print(a.equities[0])
if __name__ == '__main__':
    main()


from cpanlp.account.assets.asset import *
class InvestmentProperty(Asset):
    accounts = []
    def __init__(self, account, debit, date,tenant,address,income):
        super().__init__(account, debit, date)
        self.address = address
        self.income = income
        self.tenant = tenant
        InvestmentProperty.accounts.append(self)

        


from cpanlp.person.consumer import *

class Partner(Consumer):
    def __init__(self, name, age,wealth,utility_function,share):
        super().__init__(name, age,wealth,utility_function)
        self.share = share


from cpanlp.account.assets.asset import *
from cpanlp.account.assets.inventory import *
from cpanlp.account.assets.intangibleasset import *
from cpanlp.account.assets.financialasset.financialasset import *
from cpanlp.account.assets.financialasset.bankdeposit import *
from cpanlp.account.assets.financialasset.stock import *
from cpanlp.account.assets.financialasset.accountsreceivables import *
from cpanlp.account.assets.investmentproperty import *
from cpanlp.account.liabilities.liability import *
from cpanlp.account.liabilities.financialliability import *
from cpanlp.account.equities.equity import *
from cpanlp.account.cashflow.cashflow import *
from cpanlp.account.income.revenue import *
from cpanlp.calculate import *
from cpanlp.stocktrade import *
from cpanlp.nlp.nlp import *
from cpanlp.information.asymmetricinformation import *
from cpanlp.information.incentive import *
from cpanlp.entity.entity import *
from cpanlp.entity.LLC import *
from cpanlp.entity.SME import *
from cpanlp.entity.public import *
from cpanlp.entity.partnership import *
from cpanlp.stakeholder.stakeholder import *
from cpanlp.stakeholder.bank import *
from cpanlp.stakeholder.government import *
from cpanlp.stakeholder.media import *
from cpanlp.stakeholder.public import *
from cpanlp.stakeholder.ratingagency import *
from cpanlp.person.consumer import *
from cpanlp.person.craftsman import *
from cpanlp.person.creditor import *
from cpanlp.person.employee import *
from cpanlp.person.entrepreneur import *
from cpanlp.person.fiduciary import *
from cpanlp.person.beneficiary import *
from cpanlp.person.investor import *
from cpanlp.person.manager import *
from cpanlp.person.partner import *
from cpanlp.person.shareholder import *
from cpanlp.person.supervisor import *
from cpanlp.person.auditor import *
from cpanlp.control.control import *
from cpanlp.control.power import *
from cpanlp.control.influence import *
from cpanlp.conglomerate.associatecompany import *
from cpanlp.conglomerate.jointventure import *
from cpanlp.conglomerate.subsidiary import *
from cpanlp.contract.contract import *
from cpanlp.contract.laborcontract import *
from cpanlp.contract.lease import *
from cpanlp.contract.loancontract import *
from cpanlp.contract.financialinstrument import *
from cpanlp.market.market import *
from cpanlp.market.bubble import *
from cpanlp.culture.spirit import *
from cpanlp.risk.risk import *
from cpanlp.institution.institution import *
from cpanlp.abnormal.abnormal import *
from cpanlp.event.acquisition import *
from cpanlp.strategy.strategy import *
from cpanlp.decorator.decorator import *
from cpanlp.person.utility import *
from cpanlp.market.commodity import *
from cpanlp.tax.tax import *
from cpanlp.department.department import *
from cpanlp.policy.policy import *
from cpanlp.policy.dividendpolicy import *
from cpanlp.policy.accountingpolicy import *
from cpanlp.scheme.ponzischeme import *






from cpanlp.stakeholder.stakeholder import *

class Bank(Stakeholder):
    def __init__(self, name,type,capital, interests,power):
        super().__init__(name,type,capital, interests,power)
        self.loans = {}
    def grant_loan(self, company, amount):
        self.loans[company.name] = amount
        


from cpanlp.stakeholder.stakeholder import *

class Public(Stakeholder):
    def __init__(self, name,type,capital, interests,power):
        super().__init__(name,type,capital, interests,power)
        self.voice=""